#ifndef NT2_INCLUDE_FUNCTIONS_LOGICAL_NOTAND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGICAL_NOTAND_HPP_INCLUDED

#include <nt2/boolean/include/functions/logical_notand.hpp>

#endif
